program adv2d
implicit none

! ####define/undef IONC will call routines for netcdf outputs ######
#undef IONC
! ##################################################################

!========================================================================
! DECLARATIONS
!========================================================================
integer,parameter :: imax=300,kmax=100
integer :: i,k
real :: xmin,xmax,umin,umax,deltat,deltax,deltaz,temps,zmax
real, dimension(imax)      :: xxx          ! x en m
real, dimension(kmax)      :: zzz          ! z en m
real, dimension(kmax)      :: vitu,alphax  ! vent horiz et facteur alpha en x
real, dimension(imax,kmax) :: qinitial     ! concentration initiale
real, dimension(imax,kmax) :: qexact       ! solution exaxte (advection 1D)
real pi
character*5 file
integer it
integer :: nt=1001

!========================================================================
! INITIALISATIONS
!========================================================================
! Initialize constants --------------------------------------------------
xmax=3000.
zmax=1000.
umin=2.
umax=10.
pi=2.*asin(1.)

! Initialize grid -------------------------------------------------------
deltax=xmax/float(imax)
deltaz=zmax/float(kmax)
do i=1,imax ; xxx(i)=i*deltax ; enddo
do k=1,kmax ; zzz(k)=(k-0.5)*deltaz ; enddo

! Initialize tracer ------------------------------------------------------
do i=1,imax
   qinitial(i,:)=exp( -(25.*(xxx(i)-xmax/5.)/xmax)**2 )
enddo

! Initialize outputs --------------------------------------------------
#ifdef IONC
call iotd_ini('coucou.nc   ',imax,1,kmax,xxx,0.,zzz)
#endif

! alphax(z) = delta t / U(z) -------------------------------------------
deltat=0.2*deltax/umax
vitu(:)=umin+(umax-umin)*zzz(:)/zmax
alphax(:)=deltat/deltax*vitu(:)
qexact(:,:)=qinitial(:,:)

!=========================================================================
do it=1,nt ! TIME LOOP
!=========================================================================

!=========================================================================
! OUTPUTS
!=========================================================================
    if (mod(it,100)==1) then
#ifdef IONC
       print*,'ECRITURES it'
       call iotd_ecrit('qexact',kmax,'qexact','kg/kg',qexact)
#else
       file="e...."
       write(file(2:5),'(i4.4)') it
       open (10,file=file,form='formatted')
       do k=1,kmax
       do i=1,imax
          write(10,*) xxx(i),zzz(k),qexact(i,k)
       enddo
       enddo
       close(10)
#endif
    endif
    temps=it*deltat
    print*,'Pas de temps it=',it,temps

!========================================================================
! Advection en x avec un alphax independant de i
!========================================================================

    do k=1,kmax
       do i=1,imax
          qexact(i,k)=exp( -(25.*(xxx(i)-xmax/5.-vitu(k)*temps)/xmax)**2 )
       enddo
    enddo

!=========================================================================
enddo ! END OF TIME LOOP
!=========================================================================

#ifdef IONC
call iotd_fin
#endif
end
